# Contributors

## Special thanks for all the people who had helped this project so far

* [Panagis Tselentis](https://github.com/pantsel)

## I would like to join this list. How can I help the project

We're currently looking for contributions for the following:

* [ ] Documentation (readthedocs)
* [ ] Features

For more information, please refer to our [CONTRIBUTING](CONTRIBUTING.md) guide, and check our [code of conduct](CODE_OF_CONDUCT.md).
